"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.listYamlFilesForWorkspace = void 0;
const promises_1 = require("fs/promises");
const glob_promise_1 = __importDefault(require("glob-promise"));
const path_1 = __importDefault(require("path"));
// TODO return errors, don't throw
async function listYamlFilesForWorkspace(absolutePathToDefinition) {
    try {
        const stats = await (0, promises_1.lstat)(absolutePathToDefinition);
        if (stats.isFile()) {
            const relativeFilepath = path_1.default.basename(absolutePathToDefinition);
            return [
                await createFernFile({
                    relativeFilepath,
                    absoluteFilepath: absolutePathToDefinition,
                }),
            ];
        }
        else if (!stats.isDirectory()) {
            throw new Error(`${absolutePathToDefinition} is not a valid input`);
        }
    }
    catch (e) {
        throw new Error(`${absolutePathToDefinition} does not exist`);
    }
    const files = [];
    const filepaths = await (0, glob_promise_1.default)("**/*.yml", {
        cwd: absolutePathToDefinition,
    });
    for (const filepath of filepaths) {
        try {
            files.push(await createFernFile({
                relativeFilepath: filepath,
                absoluteFilepath: path_1.default.join(absolutePathToDefinition, filepath),
            }));
        }
        catch (e) {
            console.error(`Failed to read file: ${filepath}`, e);
        }
    }
    return files;
}
exports.listYamlFilesForWorkspace = listYamlFilesForWorkspace;
async function createFernFile({ relativeFilepath, absoluteFilepath, }) {
    return {
        filepath: relativeFilepath,
        fileContents: (await (0, promises_1.readFile)(absoluteFilepath)).toString(),
    };
}
